==> arg-services-1.1.0-sources.jar: de/uni_trier/recap/arg_services/mining/v1beta/MajorClaimServiceGrpc.java <==
package de.uni_trier.recap.arg_services.mining.v1beta;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.52.1)",
    comments = "Source: arg_services/mining/v1beta/major_claim.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class MajorClaimServiceGrpc {

  private MajorClaimServiceGrpc() {}

  public static final String SERVICE_NAME = "arg_services.mining.v1beta.MajorClaimService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest,
      de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse> getMajorClaimMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "MajorClaim",
      requestType = de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest.class,
      responseType = de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest,
      de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse> getMajorClaimMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest, de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse> getMajorClaimMethod;
    if ((getMajorClaimMethod = MajorClaimServiceGrpc.getMajorClaimMethod) == null) {
      synchronized (MajorClaimServiceGrpc.class) {
        if ((getMajorClaimMethod = MajorClaimServiceGrpc.getMajorClaimMethod) == null) {
          MajorClaimServiceGrpc.getMajorClaimMethod = getMajorClaimMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest, de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "MajorClaim"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse.getDefaultInstance()))
              .setSchemaDescriptor(new MajorClaimServiceMethodDescriptorSupplier("MajorClaim"))
              .build();
        }
      }
    }
    return getMajorClaimMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static MajorClaimServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<MajorClaimServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<MajorClaimServiceStub>() {
        @java.lang.Override
        public MajorClaimServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new MajorClaimServiceStub(channel, callOptions);
        }
      };
    return MajorClaimServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static MajorClaimServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<MajorClaimServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<MajorClaimServiceBlockingStub>() {
        @java.lang.Override
        public MajorClaimServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new MajorClaimServiceBlockingStub(channel, callOptions);
        }
      };
    return MajorClaimServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static MajorClaimServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<MajorClaimServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<MajorClaimServiceFutureStub>() {
        @java.lang.Override
        public MajorClaimServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new MajorClaimServiceFutureStub(channel, callOptions);
        }
      };
    return MajorClaimServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class MajorClaimServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void majorClaim(de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getMajorClaimMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getMajorClaimMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest,
                de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse>(
                  this, METHODID_MAJOR_CLAIM)))
          .build();
    }
  }

  /**
   */
  public static final class MajorClaimServiceStub extends io.grpc.stub.AbstractAsyncStub<MajorClaimServiceStub> {
    private MajorClaimServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected MajorClaimServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new MajorClaimServiceStub(channel, callOptions);
    }

    /**
     */
    public void majorClaim(de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getMajorClaimMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class MajorClaimServiceBlockingStub extends io.grpc.stub.AbstractBlockingStub<MajorClaimServiceBlockingStub> {
    private MajorClaimServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected MajorClaimServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new MajorClaimServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse majorClaim(de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getMajorClaimMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class MajorClaimServiceFutureStub extends io.grpc.stub.AbstractFutureStub<MajorClaimServiceFutureStub> {
    private MajorClaimServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected MajorClaimServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new MajorClaimServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse> majorClaim(
        de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getMajorClaimMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_MAJOR_CLAIM = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final MajorClaimServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(MajorClaimServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_MAJOR_CLAIM:
          serviceImpl.majorClaim((de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class MajorClaimServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    MajorClaimServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("MajorClaimService");
    }
  }

  private static final class MajorClaimServiceFileDescriptorSupplier
      extends MajorClaimServiceBaseDescriptorSupplier {
    MajorClaimServiceFileDescriptorSupplier() {}
  }

  private static final class MajorClaimServiceMethodDescriptorSupplier
      extends MajorClaimServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    MajorClaimServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (MajorClaimServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new MajorClaimServiceFileDescriptorSupplier())
              .addMethod(getMajorClaimMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> arg-services-1.5.5-sources.jar: de/uni_trier/recap/arg_services/mining/v1beta/MajorClaimServiceGrpc.java <==
package de.uni_trier.recap.arg_services.mining.v1beta;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.71.0)",
    comments = "Source: arg_services/mining/v1beta/major_claim.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class MajorClaimServiceGrpc {

  private MajorClaimServiceGrpc() {}

  public static final java.lang.String SERVICE_NAME = "arg_services.mining.v1beta.MajorClaimService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest,
      de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse> getMajorClaimMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "MajorClaim",
      requestType = de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest.class,
      responseType = de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest,
      de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse> getMajorClaimMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest, de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse> getMajorClaimMethod;
    if ((getMajorClaimMethod = MajorClaimServiceGrpc.getMajorClaimMethod) == null) {
      synchronized (MajorClaimServiceGrpc.class) {
        if ((getMajorClaimMethod = MajorClaimServiceGrpc.getMajorClaimMethod) == null) {
          MajorClaimServiceGrpc.getMajorClaimMethod = getMajorClaimMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest, de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "MajorClaim"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse.getDefaultInstance()))
              .setSchemaDescriptor(new MajorClaimServiceMethodDescriptorSupplier("MajorClaim"))
              .build();
        }
      }
    }
    return getMajorClaimMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static MajorClaimServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<MajorClaimServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<MajorClaimServiceStub>() {
        @java.lang.Override
        public MajorClaimServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new MajorClaimServiceStub(channel, callOptions);
        }
      };
    return MajorClaimServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports all types of calls on the service
   */
  public static MajorClaimServiceBlockingV2Stub newBlockingV2Stub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<MajorClaimServiceBlockingV2Stub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<MajorClaimServiceBlockingV2Stub>() {
        @java.lang.Override
        public MajorClaimServiceBlockingV2Stub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new MajorClaimServiceBlockingV2Stub(channel, callOptions);
        }
      };
    return MajorClaimServiceBlockingV2Stub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static MajorClaimServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<MajorClaimServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<MajorClaimServiceBlockingStub>() {
        @java.lang.Override
        public MajorClaimServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new MajorClaimServiceBlockingStub(channel, callOptions);
        }
      };
    return MajorClaimServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static MajorClaimServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<MajorClaimServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<MajorClaimServiceFutureStub>() {
        @java.lang.Override
        public MajorClaimServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new MajorClaimServiceFutureStub(channel, callOptions);
        }
      };
    return MajorClaimServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void majorClaim(de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getMajorClaimMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service MajorClaimService.
   */
  public static abstract class MajorClaimServiceImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return MajorClaimServiceGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service MajorClaimService.
   */
  public static final class MajorClaimServiceStub
      extends io.grpc.stub.AbstractAsyncStub<MajorClaimServiceStub> {
    private MajorClaimServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected MajorClaimServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new MajorClaimServiceStub(channel, callOptions);
    }

    /**
     */
    public void majorClaim(de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getMajorClaimMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service MajorClaimService.
   */
  public static final class MajorClaimServiceBlockingV2Stub
      extends io.grpc.stub.AbstractBlockingStub<MajorClaimServiceBlockingV2Stub> {
    private MajorClaimServiceBlockingV2Stub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected MajorClaimServiceBlockingV2Stub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new MajorClaimServiceBlockingV2Stub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse majorClaim(de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getMajorClaimMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do limited synchronous rpc calls to service MajorClaimService.
   */
  public static final class MajorClaimServiceBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<MajorClaimServiceBlockingStub> {
    private MajorClaimServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected MajorClaimServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new MajorClaimServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse majorClaim(de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getMajorClaimMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service MajorClaimService.
   */
  public static final class MajorClaimServiceFutureStub
      extends io.grpc.stub.AbstractFutureStub<MajorClaimServiceFutureStub> {
    private MajorClaimServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected MajorClaimServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new MajorClaimServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse> majorClaim(
        de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getMajorClaimMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_MAJOR_CLAIM = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_MAJOR_CLAIM:
          serviceImpl.majorClaim((de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getMajorClaimMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimRequest,
              de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimResponse>(
                service, METHODID_MAJOR_CLAIM)))
        .build();
  }

  private static abstract class MajorClaimServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    MajorClaimServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return de.uni_trier.recap.arg_services.mining.v1beta.MajorClaimProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("MajorClaimService");
    }
  }

  private static final class MajorClaimServiceFileDescriptorSupplier
      extends MajorClaimServiceBaseDescriptorSupplier {
    MajorClaimServiceFileDescriptorSupplier() {}
  }

  private static final class MajorClaimServiceMethodDescriptorSupplier
      extends MajorClaimServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    MajorClaimServiceMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (MajorClaimServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new MajorClaimServiceFileDescriptorSupplier())
              .addMethod(getMajorClaimMethod())
              .build();
        }
      }
    }
    return result;
  }
}
